@@ -1,13 +1,23 @@
+## no critic: TestingAndDebugging::RequireUseStrict
 package Require::HookChain;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-11-13'; # DATE
+our $DATE = '2022-11-15'; # DATE
 our $DIST = 'Require-HookChain'; # DIST
-our $VERSION = '0.003'; # VERSION
+our $VERSION = '0.004'; # VERSION
 
-use strict;
-use warnings;
-use Scalar::Util qw(blessed);
+#IFUNBUILT
+# use strict;
+# use warnings;
+# use Scalar::Util qw(blessed);
+#END IFUNBUILT
+
+# be minimalistic, to avoid loading any module
+#IFBUILT
+unless (defined &blessed) {
+    *blessed = sub { my $arg = shift; my $ref = ref $arg; $ref && $ref !~ /\A(SCALAR|ARRAY|HASH|GLOB|Regexp)\z/ };
+}
+#END IFBUILT
 
 my $our_hook; $our_hook = sub {
     my ($self, $filename) = @_;
@@ -117,7 +127,7 @@ Require::HookChain - Chainable require hook
 
 =head1 VERSION
 
-This document describes version 0.003 of Require::HookChain (from Perl distribution Require-HookChain), released on 2020-11-13.
+This document describes version 0.004 of Require::HookChain (from Perl distribution Require-HookChain), released on 2022-11-15.
 
 =head1 SYNOPSIS
 
@@ -193,6 +203,8 @@ To create your own chainable require hook, see example in L</"SYNOPSIS">. First
 you create a module under the C<Require::HookChain::*> namespace, then create a
 constructor as well as C<INC> handler.
 
+=for Pod::Coverage ^(blessed)$
+
 =head1 Require::HookChain::r OBJECT
 
 =head2 Methods
@@ -221,6 +233,39 @@ Please visit the project's homepage at L<https://metacpan.org/release/Require-Ho
 
 Source repository is at L<https://github.com/perlancar/perl-Require-HookChain>.
 
+=head1 SEE ALSO
+
+L<RHC> for convenience of using on the command-line or one-liners.
+
+=head1 AUTHOR
+
+perlancar <perlancar@cpan.org>
+
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2022, 2020, 2017 by perlancar <perlancar@cpan.org>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Require-HookChain>
@@ -229,17 +274,4 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
-=head1 SEE ALSO
-
-=head1 AUTHOR
-
-perlancar <perlancar@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2020, 2017 by perlancar@cpan.org.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
